summaryrefslogtreecommitdiffstats
path: root/twin/options.h
diff options
context:
space:
mode:
Diffstat (limited to 'twin/options.h')
-rw-r--r--twin/options.h64
1 files changed, 41 insertions, 23 deletions
diff --git a/twin/options.h b/twin/options.h
index 2c5341f81..41d1340a7 100644
--- a/twin/options.h
+++ b/twin/options.h
@@ -25,7 +25,7 @@ namespace KWinInternal
class Client;
-class Options : public KDecorationOptions
+class Options : public KDecorationOptions
{
public:
@@ -124,7 +124,7 @@ class Options : public KDecorationOptions
*/
enum AltTabStyle { KDE, CDE };
AltTabStyle altTabStyle;
-
+
// whether to see Xinerama screens separately for focus (in Alt+Tab, when activating next client)
bool separateScreenFocus;
// whether active Xinerama screen is the one with mouse (or with the active window)
@@ -138,7 +138,7 @@ class Options : public KDecorationOptions
bool xineramaMovementEnabled;
bool xineramaMaximizeEnabled;
bool xineramaFullscreenEnabled;
-
+
// number, or -1 = active screen (Workspace::activeScreen())
int xineramaPlacementScreen;
@@ -147,15 +147,16 @@ class Options : public KDecorationOptions
*/
enum MoveResizeMode { Transparent, Opaque };
- MoveResizeMode resizeMode;
MoveResizeMode moveMode;
-
+ MoveResizeMode resizeMode;
+ MoveResizeMode tilingMode;
+
static MoveResizeMode stringToMoveResizeMode( const TQString& s );
static const char* moveResizeModeToString( MoveResizeMode mode );
Placement::Policy placement;
- bool focusPolicyIsReasonable()
+ bool focusPolicyIsReasonable()
{
return focusPolicy == ClickToFocus || focusPolicy == FocusFollowsMouse;
}
@@ -190,7 +191,7 @@ class Options : public KDecorationOptions
* Animation speed (0 .. 10 )
*/
int animateMinimizeSpeed;
-
+
bool showDesktopIsMinimizeAll;
/**
@@ -205,12 +206,12 @@ class Options : public KDecorationOptions
* List of window classes to ignore PPosition size hint
*/
TQStringList ignorePositionClasses;
-
+
bool checkIgnoreFocusStealing( const Client* c );
WindowOperation operationTitlebarDblClick() { return OpTitlebarDblClick; }
- enum MouseCommand
+ enum MouseCommand
{
MouseRaise, MouseLower, MouseOperationsMenu, MouseToggleRaiseAndLower,
MouseActivateAndRaise, MouseActivateAndLower, MouseActivate,
@@ -225,7 +226,7 @@ class Options : public KDecorationOptions
MouseOpacityMore, MouseOpacityLess,
MouseNothing
};
-
+
enum MouseWheelCommand
{
MouseWheelRaiseLower, MouseWheelShadeUnshade, MouseWheelMaximizeRestore,
@@ -236,11 +237,11 @@ class Options : public KDecorationOptions
MouseCommand operationTitlebarMouseWheel( int delta )
{
- return wheelToMouseCommand( CmdTitlebarWheel, delta );
+ return wheelToMouseCommand( CmdTitlebarWheel, delta, CmdTitlebarRevWheel );
}
MouseCommand operationWindowMouseWheel( int delta )
{
- return wheelToMouseCommand( CmdAllWheel, delta );
+ return wheelToMouseCommand( CmdAllWheel, delta, CmdAllRevWheel );
}
MouseCommand commandActiveTitlebar1() { return CmdActiveTitlebar1; }
@@ -269,6 +270,13 @@ class Options : public KDecorationOptions
bool showGeometryTip();
/**
+ * @returns true if a maximized or tiled window should be reset to its original
+ * size when dragging it.
+ * @since R14.1.1
+ */
+ bool resetMaximizedWindowGeometry();
+
+ /**
* @returns A TQColor representing the colour that window drop shadows should
* be.
*/
@@ -307,25 +315,31 @@ class Options : public KDecorationOptions
*/
int shadowYOffset(bool active=true);
- enum { ElectricDisabled = 0, ElectricMoveOnly = 1, ElectricAlways = 2 };
+ enum { ActiveDisabled = 0,
+ ActiveSwitchOnMove = 1,
+ ActiveSwitchAlways = 2,
+ ActiveTileOnly = 3,
+ ActiveTileMaximize = 4 };
/**
* @returns true if electric borders are enabled. With electric borders
* you can change desktop by moving the mouse pointer towards the edge
* of the screen
*/
- int electricBorders();
+ int activeBorders();
+
+ int borderActivationDistance();
/**
* @returns the activation delay for electric borders in milliseconds.
*/
- int electricBorderDelay();
-
+ int activeBorderDelay();
+
bool topMenuEnabled() const { return topmenus; }
bool desktopTopMenu() const { return desktop_topmenu; }
-
+
// timeout before non-responding application will be killed after attempt to close
int killPingTimeout;
-
+
// Whether to hide utility windows for inactive applications.
bool hideUtilityWindowsForInactive;
@@ -362,6 +376,7 @@ class Options : public KDecorationOptions
MouseCommand CmdInactiveTitlebar2;
MouseCommand CmdInactiveTitlebar3;
MouseWheelCommand CmdTitlebarWheel;
+ bool CmdTitlebarRevWheel;
MouseCommand CmdWindow1;
MouseCommand CmdWindow2;
MouseCommand CmdWindow3;
@@ -369,11 +384,14 @@ class Options : public KDecorationOptions
MouseCommand CmdAll2;
MouseCommand CmdAll3;
MouseWheelCommand CmdAllWheel;
+ bool CmdAllRevWheel;
uint CmdAllModKey;
- int electric_borders;
- int electric_border_delay;
+ int active_borders;
+ int active_border_delay;
+ int active_border_distance;
bool show_geometry_tip;
+ bool reset_maximized_window_geometry;
bool topmenus;
bool desktop_topmenu;
TQColor shadow_colour;
@@ -395,7 +413,7 @@ class Options : public KDecorationOptions
// List of window classes for which not to use focus stealing prevention
TQStringList ignoreFocusStealingClasses;
- MouseCommand wheelToMouseCommand( MouseWheelCommand com, int delta );
+ MouseCommand wheelToMouseCommand( MouseWheelCommand com, int delta, bool revDir );
};
extern Options* options;
@@ -307,25 +315,31 @@ class Options : public KDecorationOptions
/**
- * @returns true if electric borders are enabled. With electric borders
+ * @returns true if active borders are enabled. With active borders
* you can change desktop by moving the mouse pointer towards the edge
* of the screen
@@ -307,25 +315,31 @@ class Options : public KDecorationOptions
/**
- * @returns the activation delay for electric borders in milliseconds.
+ * @returns the activation delay for active borders in milliseconds.
*/